@@ -192,7 +192,7 @@ def _fix_perm_filter(tar_obj):
     return tar_obj
 
 
-def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, force_symlinks=False, brief=False):
+def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, force_symlinks=False, brief=False, resources_dir=None, worker_resources_subpath=""):
     """
     :param ensure_upload: If True, will bypass checksum of resources directory
                           and upload resources bundle unconditionally;
@@ -207,15 +207,24 @@ def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, for
                            result in a broken link within the resource directory
                            unless you really know what you're doing.
     :type force_symlinks: boolean
+    :param resources_dir: Directory with resources to be archived and uploaded. If not given, uses `resources/`.
+    :type resources_dir: str
+    :param worker_resources_subpath: Path that will be prepended to the default directory where files are extracted on the worker.
+                                     Default is empty string, therefore files would be extracted directly to the root folder.
+                                     Example: If "home/dnanexus" is given, files will be extracted into /home/dnanexus.
+    :type worker_resources_subpath: str
     :returns: A list (possibly empty) of references to the generated archive(s)
     :rtype: list
 
-    If it exists, archives and uploads the contents of the
-    ``resources/`` subdirectory of *src_dir* to a new remote file
+    If resources_dir exists, archives and uploads the contents of the resources_dir
+    (usually ``resources/``) subdirectory of *src_dir* to a new remote file
     object, and returns a list describing a single bundled dependency in
     the form expected by the ``bundledDepends`` field of a run
     specification. Returns an empty list, if no archive was created.
     """
+    if not resources_dir:
+        resources_dir = os.path.join(src_dir, "resources")
+
     applet_spec = _get_applet_spec(src_dir)
 
     if project is None:
@@ -224,7 +233,6 @@ def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, for
         dest_project = project
         applet_spec['project'] = project
 
-    resources_dir = os.path.join(src_dir, "resources")
     if os.path.exists(resources_dir) and len(os.listdir(resources_dir)) > 0:
         target_folder = applet_spec['folder'] if 'folder' in applet_spec else folder
 
@@ -273,8 +281,7 @@ def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, for
 
                 # add an entry in the tar file for the current directory, but
                 # do not recurse!
-                tar_fh.add(dirname, arcname='.' + relative_dirname, recursive=False, filter=_fix_perm_filter)
-
+                tar_fh.add(dirname, arcname=worker_resources_subpath + relative_dirname, recursive=False, filter=_fix_perm_filter)
                 # Canonicalize the order of subdirectories; this is the order in
                 # which they will be visited by os.walk
                 subdirs.sort()
@@ -337,9 +344,7 @@ def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, for
                     # If we are to dereference, use the target fn
                     if deref_link:
                         true_filename = os.path.realpath(true_filename)
-
-                    tar_fh.add(true_filename, arcname='.' + relative_filename, filter=_fix_perm_filter)
-
+                    tar_fh.add(true_filename, arcname=worker_resources_subpath + relative_filename, filter=_fix_perm_filter)
                 # end for filename in sorted(files)
 
             # end for dirname, subdirs, files in os.walk(resources_dir):
@@ -426,7 +431,7 @@ def upload_resources(src_dir, project=None, folder='/', ensure_upload=False, for
 
 
 def upload_applet(src_dir, uploaded_resources, check_name_collisions=True, overwrite=False, archive=False,
-                  project=None, override_folder=None, override_name=None, 
+                  project=None, override_folder=None, override_name=None,
                   dry_run=False, brief=False, **kwargs):
     """
     Creates a new applet object.
